| Title: | Reconstruct Paleoclimate and Paleoecology with Leaf Physiognomy |
|---|---|
| Description: | Use leaf physiognomic methods to reconstruct mean annual temperature (MAT), mean annual precipitation (MAP), and leaf dry mass per area (Ma), along with other useful quantitative leaf traits. Methods in this package described in Lowe et al. (2024). |
| Authors: | Matthew J. Butrim [aut, cre, cph], Alexander J. Lowe [aut], Andrew G. Flynn [aut], Aly Baumgartner [aut], Daniel J. Peppe [aut], Dana L. Royer [aut] |
| Maintainer: | Matthew J. Butrim <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.3.0 |
| Built: | 2026-06-03 08:28:02 UTC |
| Source: | https://github.com/mjbutrim/dilp |
calc_lma() will typically only be called internally by lma(). It provides
the flexibility to use custom regression parameters to calculate leaf mass
per area (LMA).
calc_lma(data, params, resolution = "species")calc_lma(data, params, resolution = "species")
data |
Must include "petiole metric" or some combination of columns to calculate petiole metric such as "Blade Area", "Petiole Area", and "Petiole Width", or "Leaf Area" and "Petiole Width". If calculating morphospecies-mean LMA, must include "Site" and "Morphotype" columns. If calculating species-mean LMA, only needs to include a "Site' column. |
params |
A list of regression parameters. Must contain "stat" (= "mean" or = "variance"), "regression_slope", "y_intercept", "unexplained_mean_square", "sample_size_calibration" "mean_log_petiole_metric_calibration", "sum_of_squares_calibration", and "critical_value". Pre-loaded sets of parameters:
|
resolution |
Either "species" or "site". Informs whether the function should calculate morphospecies-mean LMA values ("species") or site-mean/site- variance LMA values ("site"). If resolution = "site", data must already be in the form of species-mean LMA. |
A table with LMA results
Royer, D. L., L. Sack, P. Wilf, C. H. Lusk, G. J. Jordan, Ulo Niinemets, I. J. Wright, et al. 2007. Fossil Leaf Economics Quantified: Calibration, Eocene Case Study, and Implications. Paleobiology 33: 574–589
Lowe, A. J., D. L. Royer, D. J. Wieczynski, M. J. Butrim, T. Reichgelt, L. Azevedo-Schmidt, D. J. Peppe, et al. 2024. Global patterns in community-scale leaf mass per area distributions of woody non-monocot angiosperms and their utility in the fossil record. In review.
# Calculate morphospecies-mean LMA values with the parameters from Royer et al. (2007) results <- calc_lma(McAbeeExample, params = list( stat = "mean", regression_slope = 0.382, y_intercept = 3.070, unexplained_mean_square = 0.032237, sample_size_calibration = 667, mean_log_petiole_metric_calibration = -3.011, sum_of_squares_calibration = 182.1, critical_value = 1.964 ), resolution = "species" ) results # Calculate site-mean LMA values with the parameters from Lowe et al. (2024) entered from scratch site_results <- calc_lma(results, params = list( stat = "mean", regression_slope = 0.345, y_intercept = 2.954, unexplained_mean_square = 0.01212861, sample_size_calibration = 70, mean_log_petiole_metric_calibration = -2.902972, sum_of_squares_calibration = 1.154691, critical_value = 1.995469 ), resolution = "site" ) site_results# Calculate morphospecies-mean LMA values with the parameters from Royer et al. (2007) results <- calc_lma(McAbeeExample, params = list( stat = "mean", regression_slope = 0.382, y_intercept = 3.070, unexplained_mean_square = 0.032237, sample_size_calibration = 667, mean_log_petiole_metric_calibration = -3.011, sum_of_squares_calibration = 182.1, critical_value = 1.964 ), resolution = "species" ) results # Calculate site-mean LMA values with the parameters from Lowe et al. (2024) entered from scratch site_results <- calc_lma(results, params = list( stat = "mean", regression_slope = 0.345, y_intercept = 2.954, unexplained_mean_square = 0.01212861, sample_size_calibration = 70, mean_log_petiole_metric_calibration = -2.902972, sum_of_squares_calibration = 1.154691, critical_value = 1.995469 ), resolution = "site" ) site_results
Temperature and precipitation data associated with the modern localities used to calibrate the DiLP model
climate_calibration_dataclimate_calibration_data
climate_calibration_dataA data frame with 92 rows and 5 columns:
Locality name
Mean Annual Temperature (celsius)
Mean Annual Precipitation (mm)
Koppen climate classifcations
Whittaker climate classifications
Peppe et al. 2011
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
dilp() processes raw leaf physiognomic data, checks for common
errors/outliers, and returns the processed data, keys to finding potential
errors or outliers, and paleoclimate reconstructions.
dilp(specimen_data, params = "PeppeGlobal", subsite_cols = NULL)dilp(specimen_data, params = "PeppeGlobal", subsite_cols = NULL)
specimen_data |
A data frame containing specimen level leaf physiognomic
data. See Lowe et al. 2024 for more information on how to collect this data.
A good reference for how to put together the data: Required columns:
Recommended columns:
|
params |
Either a string referring to one of two preloaded parameter sets of a list of custom parameters (same format as the list below). Preloaded parameter sets are "PeppeGlobal" and "PeppeNH" which are calibrated based on global and northern hemisphere data respectively. Allen et al. (2020) illustrates a situation in which the northern hemisphere parameters may be preferable. The "PeppeNH" parameters only estimate MAT. Use "PeppeGlobal" for all MAP estimates. Defaults to "PeppeGlobal" as follows (Peppe et al. 2011):
|
subsite_cols |
A vector or list of columns present in |
A list of tables that includes all pertinent DiLP information:
processed_leaf_data: the full set of cleaned and newly calculated leaf
physiognomic data that is necessary for DiLP analysis. See dilp_processing()
for more information.
processed_morphotype_data: morphospecies-site pair means for all leaf physiognomic data.
processed_site_data: site means for all leaf physiognomic data.
errors: lists any specimens that may be causing common errors in DiLP
calculations. See dilp_errors() for more information.
outliers: flags outliers in variables used for DiLP analysis that may
represent incorrect data. See dilp_outliers() for more information.
results: climate reconstructions of MAT and MAP using single and multi-linear regressions.
Allen, S. E., Lowe, A. J., Peppe, D. J., & Meyer, H. W. (2020). Paleoclimate and paleoecology of the latest Eocene Florissant flora of central Colorado, USA. Palaeogeography, Palaeoclimatology, Palaeoecology, 551, 109678.
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
Lowe. A.J., Flynn, A.G., Butrim, M.J., Baumgartner, A., Peppe, D.J., and Royer, D.L. (2024), Reconstructing terrestrial paleoclimate and paleoecology with fossil leaves using Digital Leaf Physiognomy and leaf mass per area. J. Vis. Exp. (212), e66838, doi:10.3791/66838 (2024).
dilp_results <- dilp(McAbeeExample) dilp_results$processed_leaf_data dilp_results$processed_morphotype_data dilp_results$processed_site_data dilp_results$errors dilp_results$outliers dilp_results$resultsdilp_results <- dilp(McAbeeExample) dilp_results$processed_leaf_data dilp_results$processed_morphotype_data dilp_results$processed_site_data dilp_results$errors dilp_results$outliers dilp_results$results
dilp_cca plots a canonical correspondence analysis (CCA) ordination of the leaf
physiognomic space represented in the calibration dataset of Peppe et al. (2011).
The fossil sites being tested are placed along the CCA axes. If a fossil site
falls outside of the plotted calibration space, paleoclimate reconstructions
for that fossil site should be treated with caution.
dilp_cca( dilp_table, physiognomy_calibration = physiognomy_calibration_data, climate_calibration = climate_calibration_data, colorby = "data" )dilp_cca( dilp_table, physiognomy_calibration = physiognomy_calibration_data, climate_calibration = climate_calibration_data, colorby = "data" )
dilp_table |
The results of a call to |
physiognomy_calibration |
A physiognomic calibration dataset. Defaults to an internal version of
|
climate_calibration |
A climate calibration dataset. Defaults to an internal version of
|
colorby |
One of "data", "koppen", "whittaker". Defaults to data, which colors points by whether they are from the calibration data or not. Koppen and Whittaker are works in progress. |
A ggplot2 plot
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
results <- dilp(McAbeeExample) dilp_cca(results)results <- dilp(McAbeeExample) dilp_cca(results)
dilp_errors() will typically only be called internally by dilp().
However, it can be used on its own to evaluate errors that commonly occur
during the data collection and processing steps. A dilp_errors() call
will nearly always follow a dilp_processing() call. Returns a data frame.
dilp_errors(specimen_data)dilp_errors(specimen_data)
specimen_data |
Processed specimen level leaf physiognomic data. The
structure should match the structure of the output from |
A 7 by X data frame. Each row shows a common error, and which specimens from the input dataset are tripping it.
# Check for errors in the provided McAbeeExample dataset. dilp_dataset <- dilp_processing(McAbeeExample) dilp_errors <- dilp_errors(dilp_dataset) dilp_errors# Check for errors in the provided McAbeeExample dataset. dilp_dataset <- dilp_processing(McAbeeExample) dilp_errors <- dilp_errors(dilp_dataset) dilp_errors
dilp_outliers() is called internally by dilp().
However, it can be used on its own to flag specimens that may have been
reported, measured, or prepared incorrectly. dilp_outliers() returns a data frame
listing specimens that have unusually high or low values for the four key
parameters used in DiLP analyses. This includes whether a specimen is an outlier
in the entire dataset, or among other specimens in the same morphotype. If flagged, we suggest looking at the
raw measurements and prepped specimen and evaluating if the data is in error or is correct. If in error, the specimen will
need to be reprepared and/or remeasured, and the updated datasheet re-read back into R.
dilp_outliers(specimen_data)dilp_outliers(specimen_data)
specimen_data |
Processed specimen level leaf physiognomic data. The
structure should match the structure of the output from |
A 4 by X data frame. Each row represents one of the DiLP parameters, and the specimens that are outliers for that parameter.
# Check for outliers in the provided McAbeeExample dataset. Each # of these outliers has been manually re-examined and was found acceptable. dilp_dataset <- dilp_processing(McAbeeExample) dilp_outliers <- dilp_outliers(dilp_dataset) dilp_outliers# Check for outliers in the provided McAbeeExample dataset. Each # of these outliers has been manually re-examined and was found acceptable. dilp_dataset <- dilp_processing(McAbeeExample) dilp_outliers <- dilp_outliers(dilp_dataset) dilp_outliers
dilp_processing() will typically only be called internally by dilp().
However, it can be used on its own to generate and view a processed DiLP
dataset that includes raw and derived physiognomic values useful for DiLP and
other physiognomic analyses. Returns a data frame.
dilp_processing(specimen_data)dilp_processing(specimen_data)
specimen_data |
A data frame containing specimen level leaf physiognomic
data. A good reference for how to put together the data: |
A data frame containing cleaned and processed specimen level leaf physiognomic data. New variables calculated are:
Leaf area
Feret diameter
Feret diameter ratio (FDR)
Raw blade perimeter corrected (Raw blade perimeter - length of cut perimeter)
Internal raw blade perimeter corrected (Internal raw blade perimeter - length of cut perimeter)
Total tooth count
Total tooth count : internal perimeter (TC:IP)
Perimeter ratio
Petiole metric
Aspect ratio
Shape factor
Compactness
Tooth area
Tooth area : perimeter (TA:P)
Tooth area: internal perimeter (TA:IP)
Tooth area : blade area (TA:BA)
Average primary tooth area (Avg TA)
Tooth count : blade area (TC:BA)
Tooth count : perimeter (TC:P)
dilp_dataset <- dilp_processing(McAbeeExample) dilp_datasetdilp_dataset <- dilp_processing(McAbeeExample) dilp_dataset
dilp_whittaker() plots dilp() outputs onto a Whittaker Biome plot. Base
Whittaker Plot from the plotbiomes
package by Ștefan Valentin and Sam Levin.
dilp_whittaker(climate_data)dilp_whittaker(climate_data)
climate_data |
A data frame containing either the direct output of a
|
A modifiable ggplot with dilp climate-reconstructed sites plotted onto a Whittaker diagram.
Valentin Ștefan, & Sam Levin. (2018). plotbiomes: R package for plotting Whittaker biomes with ggplot2 (v1.0.0). Zenodo. https://doi.org/10.5281/zenodo.7145245
results <- dilp(McAbeeExample) dilp_whittaker(results)results <- dilp(McAbeeExample) dilp_whittaker(results)
lma() takes either raw or processed leaf physiognomic data and returns
leaf mass per area (LMA) reconstructions of species-mean, site-mean, and site-
variance.
lma() calls calc_lma() multiple times with different sets of
parameters. See calc_lma() for more control over LMA reconstructions.
lma(specimen_data)lma(specimen_data)
specimen_data |
A table that must include "Site", "Morphotype", and either "Petiole Metric", or "Blade Area", "Petiole Area", and "Petiole Width". |
A list of tables containing leaf mass per area reconstructions.
species_mean_lma contains the average LMA for each morphospecies-site pair. Values calculated using the regression from Royer et al. (2007).
royer_site_mean_lma contains the average LMA for each site. Values calculated using the regression from Royer et al. (2007)
lowe_site_lma contains the average LMA for each site. Values calculated using the regression from Lowe et al. (2024)
lowe_variance contains the variance in LMA for each site. Values calculated using the regression from Lowe et al. (2024)
Royer, D. L., L. Sack, P. Wilf, C. H. Lusk, G. J. Jordan, Ulo Niinemets, I. J. Wright, et al. 2007. Fossil Leaf Economics Quantified: Calibration, Eocene Case Study, and Implications. Paleobiology 33: 574–589
Lowe, A. J., D. L. Royer, D. J. Wieczynski, M. J. Butrim, T. Reichgelt, L. Azevedo-Schmidt, D. J. Peppe, et al. 2024. Global patterns in community-scale leaf mass per area distributions of woody non-monocot angiosperms and their utility in the fossil record. In review.
results <- lma(McAbeeExample) resultsresults <- lma(McAbeeExample) results
Leaf physiognomic data of specimens collected from the McAbee Fossil Beds in British Columbia, Canada (Lowe et al. 2018).
McAbeeExampleMcAbeeExample
McAbeeExampleA data frame with 192 rows and 18 columns:
Stratigraphic layer or locality
Repository number for individual specimen
Morphotype the specimen belongs to
Additional notes about the specimen or its measurements
Whether the margin is toothed (0) or entire (1)
The width of the petiole at the basalmost point of insertion into the leaf lamina
The reconstructed area of the leaf lamina, not including the petiole
The length of the perimeter of the leaf lamina, not including the petiole
The diameter of a circle with the same area as the leaf lamina, not including the petiole
The longest line that can be drawn between two points on the perimeter of a selection that is perpendicular to Feret length. Approximates blade width.
The area of a leaf prepared for tooth measurements that still has its teeth.
The perimeter of a leaf prepared for tooth measurements that still has its teeth.
The area of a leaf prepared for tooth measurements with teeth digitally removed.
The perimeter of a leaf prepared for tooth measurements with teeth digitally removed.
The total length of all segments of leaf removed from the leaf blade while removing damage during preparation of the leaf.
The number of primary teeth along the undamaged perimeter
The number of secondary teeth along the undamaged perimeter
Lowe et al. 2018
Lowe, A. J., D. R. Greenwood, C. K. West, J. M. Galloway, M. Sudermann, and T. Reichgelt. 2018. Plant community ecology and climate on an upland volcanic landscape during the Early Eocene Climatic Optimum: McAbee Fossil Beds, British Columbia, Canada. Palaeogeography, Palaeoclimatology, Palaeoecology 511: 433–448.
Leaf physiognomic data taken from the modern localities used to calibrate the DiLP model
physiognomy_calibration_dataphysiognomy_calibration_data
physiognomy_calibration_dataA data frame with 92 rows and 12 columns:
Locality name
Average leaf area at site
Feret diameter:Feret length. Describes leaf linearity compared to a circle
Ratio - Raw blade perimeter:Internal raw blade perimeter
Ratio - Tooth count:Perimeter
Ratio - Tooth count:Internal perimeter
Average area of a primary tooth
Ratio - Tooth area:Blade area
Ratio - Tooth area:Perimeter
Ratio - Tooth area:Internal perimeter
Ratio - Tooth count:Blade area
Percentage of untoothed species at the site
Peppe et al. 2011
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
precip_slr() will produce estimates of mean annual precipitation and standard error
using leaf area analysis.
precip_slr( data, regression = "Peppe2018", slope = NULL, constant = NULL, error = NULL )precip_slr( data, regression = "Peppe2018", slope = NULL, constant = NULL, error = NULL )
data |
A data frame that must include the columns "morphotype", "leaf_area", and "specimen_number". Must be leaf level data. |
regression |
A string representing one of the following pre-loaded regressions:
|
slope |
Slope, if using a custom regression |
constant |
Constant, if using a custom regression |
error |
Standard error, if using a custom regression |
A table with MAP estimates for each site
Peppe, D. J., Baumgartner, A., Flynn, A., & Blonder, B. (2018). Reconstructing paleoclimate and paleoecology using fossil leaves. Methods in paleoecology: Reconstructing Cenozoic terrestrial environments and ecological communities, 289-317.
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
Jacobs, B. F. (2002). Estimation of low-latitude paleoclimates using fossil angiosperm leaves: examples from the Miocene Tugen Hills, Kenya. Paleobiology, 28, 399–421.
Wilf, P. (2008). Fossil angiosperm leaves: paleobotany’s difficult children prove themselves. Paleontological Society Papers, 14, 319–333.
precip_slr(McAbeeExample, regression = "Peppe2011")precip_slr(McAbeeExample, regression = "Peppe2011")
temp_slr() will produce estimates of mean annual temperature and standard error
using leaf margin analysis. There are different ways to represent error. The most simple is using the standard error of the regression.
These are listed in the table below. However, this is not the only source of uncertainty and is too simplistic a measure of error.
This function instead uses the method outlined in Miller et al. 2006, and reported in Peppe et al 2018 (eq. 4), which also accounts
for binomial sampling error and overdispersion, offering what we consider a best practice approach. The standard error of the regression provides a minimum error value.
Note, Peppe et al. 2018 suggests that a conservative minimum uncertainty for all leaf margin analysis results is probably +/- 5 degrees Celsius.
Standard error of regression:
| Regression | SE |
| Peppe2018 | 4.5 |
| Peppe2011 | 4.8 |
| Peppe2011NH | 3.4 |
| Miller2006 | - |
| WingGreenwood | 0.8 |
| Wilf1997 | 2.0 |
| KowalskiDilcher | 3.6 |
temp_slr( data, regression = "Peppe2018", slope = NULL, constant = NULL, error = NULL )temp_slr( data, regression = "Peppe2018", slope = NULL, constant = NULL, error = NULL )
data |
A data frame that must include the columns "morphotype" and "margin". Can be leaf or species level data. |
regression |
A string representing one of the following pre-loaded regressions:
|
slope |
Slope, if using a custom regression |
constant |
Constant, if using a custom regression |
error |
Standard error, if using a custom regression |
A table with MAT estimates for each site
Kowalski, E.A. & Dilcher, D.L. (2003). Warmer paleotemperatures for terrestrial ecosystems. Proceedings of the National Academy of Sciences, 100, 167–170.
Miller, I. M., Brandon, M. T., & Hickey, L. J. (2006). Using leaf margin analysis to estimate mid-Cretaceous (Albian) paleolatitude of the Baja BC block. Earth and Planetary Science Letters, 245, 95–114.
Peppe, D. J., Baumgartner, A., Flynn, A., & Blonder, B. (2018). Reconstructing paleoclimate and paleoecology using fossil leaves. Methods in paleoecology: Reconstructing Cenozoic terrestrial environments and ecological communities, 289-317.
Peppe, D.J., Royer, D.L., Cariglino, B., Oliver, S.Y., Newman, S., Leight, E., Enikolopov, G., Fernandez-Burgos, M., Herrera, F., Adams, J.M., Correa, E., Currano, E.D., Erickson, J.M., Hinojosa, L.F., Hoganson, J.W., Iglesias, A., Jaramillo, C.A., Johnson, K.R., Jordan, G.J., Kraft, N.J.B., Lovelock, E.C., Lusk, C.H., Niinemets, Ü., Peñuelas, J., Rapson, G., Wing, S.L. and Wright, I.J. (2011), Sensitivity of leaf size and shape to climate: global patterns and paleoclimatic applications. New Phytologist, 190: 724-739. https://doi.org/10.1111/j.1469-8137.2010.03615.x
Wing, S., & Greenwood, D. R. (1993). Fossils and fossil climate: the case for equable continental interiors in the Eocene. Philosophical Transactions of the Royal Society of London Series B, 341, 243–252.
Wilf, P. (1997). When are leaves good thermometers? A new case for leaf margin analysis. Paleobiology, 23, 373–390.
temp_slr(McAbeeExample, regression = "Peppe2011")temp_slr(McAbeeExample, regression = "Peppe2011")
View preloaded regressions
view_regressions(type)view_regressions(type)
type |
Must be either "dilp", "lma", temp", or "precip". |
A data frame containing the parameters for each available regression of the selected type.
view_regressions("dilp")view_regressions("dilp")
Delineations of Whittaker biomes from github.com/valentinitnelav/plotbiomes
Whittaker_biomesWhittaker_biomes
Whittaker_biomesA data frame with points mapping out Whittaker biome delineations.
github.com/valentinitnelav/plotbiomes
*Valentin Ștefan, & Sam Levin. (2018). plotbiomes: R package for plotting Whittaker biomes with ggplot2 (v1.0.0). Zenodo. https://doi.org/10.5281/zenodo.7145245